@@ -3,7 +3,7 @@
 *                       F i l e   S t r e a m   C l a s s                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFileStream.h,v 1.11 2005/02/08 03:23:28 fox Exp $                      *
+* $Id: FXFileStream.h,v 1.15 2006/01/22 17:58:01 fox Exp $                      *
 ********************************************************************************/
 #ifndef FXFILESTREAM_H
 #define FXFILESTREAM_H
@@ -33,11 +33,11 @@ namespace FX {
 
 /// File Store Definition
 class FXAPI FXFileStream : public FXStream {
-private:
-  FXint file;
 protected:
-  virtual unsigned long writeBuffer(unsigned long count);
-  virtual unsigned long readBuffer(unsigned long count);
+  FXFile file;
+protected:
+  virtual FXuval writeBuffer(FXuval count);
+  virtual FXuval readBuffer(FXuval count);
 public:
 
   /// Create file store
@@ -47,16 +47,16 @@ public:
   * Open binary data file stream; allocate a buffer of the given size
   * for the file I/O; the buffer must be at least 16 bytes.
   */
-  FXbool open(const FXString& filename,FXStreamDirection save_or_load,unsigned long size=8192);
+  bool open(const FXString& filename,FXStreamDirection save_or_load,FXuval size=8192);
 
   /// Close file store
-  virtual FXbool close();
+  virtual bool close();
 
   /// Get position
   FXlong position() const { return FXStream::position(); }
 
   /// Move to position
-  virtual FXbool position(FXlong offset,FXWhence whence=FXFromStart);
+  virtual bool position(FXlong offset,FXWhence whence=FXFromStart);
 
   /// Save single items to stream
   FXFileStream& operator<<(const FXuchar& v){ FXStream::operator<<(v); return *this; }
@@ -71,16 +71,16 @@ public:
   FXFileStream& operator<<(const FXulong& v){ FXStream::operator<<(v); return *this; }
 
   /// Save arrays of items to stream
-  FXFileStream& save(const FXuchar* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXchar* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXushort* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXshort* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXuint* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXint* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXfloat* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXdouble* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXlong* p,unsigned long n){ FXStream::save(p,n); return *this; }
-  FXFileStream& save(const FXulong* p,unsigned long n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXuchar* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXchar* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXushort* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXshort* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXuint* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXint* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXfloat* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXdouble* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXlong* p,FXuval n){ FXStream::save(p,n); return *this; }
+  FXFileStream& save(const FXulong* p,FXuval n){ FXStream::save(p,n); return *this; }
 
   /// Load single items from stream
   FXFileStream& operator>>(FXuchar& v){ FXStream::operator>>(v); return *this; }
@@ -95,16 +95,16 @@ public:
   FXFileStream& operator>>(FXulong& v){ FXStream::operator>>(v); return *this; }
 
   /// Load arrays of items from stream
-  FXFileStream& load(FXuchar* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXchar* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXushort* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXshort* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXuint* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXint* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXfloat* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXdouble* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXlong* p,unsigned long n){ FXStream::load(p,n); return *this; }
-  FXFileStream& load(FXulong* p,unsigned long n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXuchar* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXchar* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXushort* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXshort* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXuint* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXint* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXfloat* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXdouble* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXlong* p,FXuval n){ FXStream::load(p,n); return *this; }
+  FXFileStream& load(FXulong* p,FXuval n){ FXStream::load(p,n); return *this; }
 
   /// Save object
   FXFileStream& saveObject(const FXObject* v){ FXStream::saveObject(v); return *this; }
