@@ -3,7 +3,7 @@
 *                            X P M   I m a g e   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXXPMImage.h,v 1.18 2005/01/16 16:06:06 fox Exp $                        *
+* $Id: FXXPMImage.h,v 1.21 2006/01/22 17:58:13 fox Exp $                        *
 ********************************************************************************/
 #ifndef FXXPMIMAGE_H
 #define FXXPMIMAGE_H
@@ -41,16 +41,17 @@ private:
   FXXPMImage &operator=(const FXXPMImage&);
 public:
   static const FXchar fileExt[];
+  static const FXchar mimeType[];
 public:
 
   /// Construct image from compiled-in X Pixmap format
   FXXPMImage(FXApp* a,const FXchar **pix=NULL,FXuint opts=0,FXint w=1,FXint h=1);
 
   /// Save pixels into stream in X Pixmap format
-  virtual FXbool savePixels(FXStream& store) const;
+  virtual bool savePixels(FXStream& store) const;
 
   /// Load pixels from stream in X Pixmap format
-  virtual FXbool loadPixels(FXStream& store);
+  virtual bool loadPixels(FXStream& store);
 
   /// Destroy icon
   virtual ~FXXPMImage();
@@ -63,7 +64,7 @@ public:
 /**
 * Check if stream contains a XPM, return TRUE if so.
 */
-extern FXAPI FXbool fxcheckXPM(FXStream& store);
+extern FXAPI bool fxcheckXPM(FXStream& store);
 
 
 /**
@@ -71,7 +72,7 @@ extern FXAPI FXbool fxcheckXPM(FXStream& store);
 * Upon successful return, the pixel array and size are returned.
 * If an error occurred, the pixel array is set to NULL.
 */
-extern FXAPI FXbool fxloadXPM(const FXchar **pix,FXColor*& data,FXint& width,FXint& height);
+extern FXAPI bool fxloadXPM(const FXchar **pix,FXColor*& data,FXint& width,FXint& height);
 
 
 /**
@@ -79,13 +80,13 @@ extern FXAPI FXbool fxloadXPM(const FXchar **pix,FXColor*& data,FXint& width,FXi
 * Upon successful return, the pixel array and size are returned.
 * If an error occurred, the pixel array is set to NULL.
 */
-extern FXAPI FXbool fxloadXPM(FXStream& store,FXColor*& data,FXint& width,FXint& height);
+extern FXAPI bool fxloadXPM(FXStream& store,FXColor*& data,FXint& width,FXint& height);
 
 
 /**
 * Save an XPM (X Pixmap) file to a stream.
 */
-extern FXAPI FXbool fxsaveXPM(FXStream& store,const FXColor *data,FXint width,FXint height,FXbool fast=TRUE);
+extern FXAPI bool fxsaveXPM(FXStream& store,const FXColor *data,FXint width,FXint height,bool fast=true);
 
 #endif
 
